@@ -5,7 +5,13 @@ from recap.config import settings
 from rich import print_json
 
 
-app = typer.Typer(help="Read and search the data catalog.")
+app = typer.Typer(help="""
+    Read and search the data catalog.
+
+    Recap's `recap catalog` command reads metadata Recap's data catalog. List
+    the catalog's directory structure with `recap list`, read metadata from a
+    directory with `recap read`, and search with `recap search`.
+""")
 
 
 @app.command()
@@ -18,8 +24,19 @@ def search(
     ),
 ):
     """
-    Searches the data catalog. The query string syntax is dependent on the data
-    catalog.
+    Searches the data catalog.
+
+    \b
+    Recap's search syntax depends on the catalog plugin that's used. Recap
+    stores its metadata in SQLite by default. You can use SQLite's json_extract
+    syntax to search the catalog:
+
+    \b
+        recap catalog search "json_extract(metadata, '$.\"db.location\".table') = 'some_table'"
+
+    \b
+    The database file defaults to `~/.recap/catalog/recap.db`, if you wish to
+    open a SQLite client directly.
     """
 
     with catalogs.create_catalog(**settings('catalog', {})) as c:
